@@ -37,12 +37,15 @@ public:
 	enum blackList { BlacklistNone, BlacklistThis, BlacklistAll };
 
 	explicit BlacklistSelect(Package* pkg, QWidget *parent = 0);
-    ~BlacklistSelect();
+	virtual ~BlacklistSelect();
 
 protected:
     void changeEvent(QEvent *e);
 
 private:
+	BlacklistSelect(const BlacklistSelect& old);
+	BlacklistSelect operator= (const BlacklistSelect& old);
+
     Ui::BlacklistSelect *ui;
 	Package* iPkg;
 
