@@ -8,11 +8,14 @@ class DpkgInterface : public QObject
     Q_OBJECT
 public:
     explicit DpkgInterface(QObject *parent = 0);
+	virtual ~DpkgInterface();
+
 	bool loadDebFiles(QStringList files_);
 
-signals:
 
-public slots:
+private:
+	DpkgInterface(const DpkgInterface& old);
+	DpkgInterface operator= (const DpkgInterface& old);
 
 };
 
