@@ -59,11 +59,14 @@ LogView::~LogView()
 
 int LogView::exec()
 {
+	/*
 #ifdef Q_WS_MAEMO_5		// workaround for buggy Qt autorotation
 	QRect r = dynamic_cast<QWidget*>(this->parent())->rect();
 	if(r.width() < r.height())
 		this->setAttribute(Qt::WA_Maemo5PortraitOrientation);
 #endif
+	*/
+
 	show();
 
 	//ui->plainTextEdit->setMinimumHeight( ui->plainTextEdit->contentsRect().height() );
@@ -83,9 +86,12 @@ int LogView::exec()
 
 	int e = QDialog::exec();
 
+	/*
 #ifdef Q_WS_MAEMO_5		// workaround for buggy Qt autorotation
 	this->setAttribute(Qt::WA_Maemo5AutoOrientation);
 #endif
+	*/
+
 	return e;
 }
 
@@ -114,5 +120,7 @@ void LogView::on_btnCopy_clicked()
 	ui->plainTextEdit->selectAll();
 	ui->plainTextEdit->copy();
 
+#ifdef Q_WS_MAEMO_5
 	QMaemo5InformationBox::information ( this, "Copied" );
+#endif
 }
