@@ -19,8 +19,7 @@ extern "C"
 
 extern "C"
 {
-#include <sys/vfs.h>
-#include <unistd.h>
+    #include <sys/vfs.h>
 }
 
 #include "mainwindow.h"
@@ -121,16 +120,6 @@ MainWindow::MainWindow(QWidget *parent) :
         }
     }
 
-    // workaround for Trolltech.conf getting owned by root..
-#ifdef Q_WS_MAEMO_5
-    QFileInfo trollConf("/home/user/.config/Trolltech.conf");
-    if( trollConf.exists() && trollConf.ownerId() == 0 )
-    {
-        uint uid = 29999; // "user" (maemo5)
-        uint gid = 29999; // "users" (maemo5)
-        chown(trollConf.absoluteFilePath().toAscii(), uid, gid);
-    }
-#endif
 
     iMediaObject = new Phonon::MediaObject(this);
     Phonon::AudioOutput* aout = new Phonon::AudioOutput(Phonon::NotificationCategory, this);
