@@ -48,7 +48,10 @@ public:
 	enum nextOperation { OpNone, OpPromptSimulated, OpOpenPkgView };
 
     explicit MainWindow(QWidget *parent = 0);
-    ~MainWindow();
+	virtual ~MainWindow();
+
+	void openNetworkConnection();
+
 	void operationQueueFinished(QList<AAptInterface::interfaceMode> lastModes, bool success, QString title, QStringList msgs);
 	void busyDialog(bool show_, QString title="", QString text="");
 	void closeEvent(QCloseEvent *event);
@@ -58,6 +61,7 @@ public:
 	void setNextOperation(nextOperation op_) { iNextOperation=op_; }
 
 	void on_btnUpdate_clicked();
+	void resizeEvent(QResizeEvent* event);
 
 public slots:
 	void orientationChanged();
@@ -69,8 +73,12 @@ protected:
     void changeEvent(QEvent *e);
 
 private:
+	MainWindow(const MainWindow& old);
+	MainWindow operator= (const MainWindow& old);
+
 	void dateFetchAsk();
 	void showFreeSpace();
+	void rescaleMenuView();
 
     Ui::MainWindow *ui;
 	AAptInterface* iAptInterface;
@@ -85,6 +93,8 @@ private:
 	bool iUpgradeAutoUpdate;
 	nextOperation iNextOperation;
 	Phonon::MediaObject* iMediaObject;
+	QNetworkSession* iNetworkSession;
+	QNetworkConfigurationManager* iNetworkConfigurationManager;
 
 	void on_btnRepos_clicked();
 	void on_btnUpgrade_clicked();
@@ -93,7 +103,7 @@ private:
 
 private slots:
 	void on_listWidget_itemClicked(QListWidgetItem* item);
- void on_actionLoad_file_triggered();
+	void on_actionLoad_file_triggered();
 	void on_actionOptions_triggered();
 	void on_actionView_log_triggered();
 	void on_actionClean_triggered();
