@@ -21,9 +21,11 @@
 #include "package.h"
 #include "repository.h"
 #include "aaptinterface.h"
-#include "apt-src/debversion.h"
 #include "blacklistselect.h"
 
+#include "apt-src/debversion.h"
+
+
 Package::Package(QByteArray name_, AAptInterface *apt_):
 		iAptInterface(apt_), iName(name_), iIsInstalled(false), iMarkedForOperation(false),
 		iPkgStatus(PkgStatUnknown), iSize(0), iInstalledSize(0), iMarkedOperation(PkgOpNone),
@@ -33,11 +35,13 @@ Package::Package(QByteArray name_, AAptInterface *apt_):
 
 Package::~Package()
 {
-	if( iIcon != 0 )
+	if( iIcon ) {
 		delete iIcon;
+		iIcon=0;
+	}
 }
 
-QString Package::displayName()
+QString Package::displayName() const
 {
 	QString pkgname = name();
 	if( !iMaemoDisplayName.isEmpty() )
@@ -48,7 +52,7 @@ QString Package::displayName()
 	return pkgname;
 }
 
-QString Package::fileName()
+QString Package::fileName() const
 {
 	if( iFullFileNames.count()>0 ) {
 		return iFullFileNames.at(0).mid( iFullFileNames.at(0).lastIndexOf('/')+1 );
@@ -88,7 +92,7 @@ void Package::convertIcon()
 	}
 }
 
-bool Package::isUpgradeable()
+bool Package::isUpgradeable() const
 {
 	if( iSection=="user/hidden" || iPinned )
 		return false;
@@ -103,7 +107,7 @@ bool Package::isUpgradeable()
 	return false;
 }
 
-QString Package::upgradeableVersion()
+QString Package::upgradeableVersion() const
 {
 	QString ver;
 	if( isInstalled() ) {
@@ -114,7 +118,7 @@ QString Package::upgradeableVersion()
 	return ver;
 }
 
-Package* Package::availablePackage()
+Package* Package::availablePackage() const
 {
 	if( !isInstalled() )
 		return 0;
@@ -141,7 +145,7 @@ Package::packageStatus Package::status()
 	return iPkgStatus;
 }
 
-bool Package::hasIconData()
+bool Package::hasIconData() const
 {
 	if( iIconData.length()>0 )
 		return true;
@@ -176,7 +180,7 @@ QStringList Package::toTrimmedRichTextList(QList<QByteArray> list_in)
 	return list_out;
 }
 
-QStringList Package::checkConflicts_RichText()
+QStringList Package::checkConflicts_RichText() const
 {
 	QStringList list;
 
@@ -256,7 +260,7 @@ bool Package::versionConflicts(QString conflictVer, QString operVer)
 	return confl;
 }
 
-QString Package::maintainerRichText()
+QString Package::maintainerRichText() const
 {
 	QString m = iMaintainer;
 	m.replace('<',"&lt;");
