@@ -27,14 +27,19 @@ class RotatingBackground : public QWidget
     Q_OBJECT
 public:
     explicit RotatingBackground(QWidget *parent = 0);
+	virtual ~RotatingBackground();
+
 	void loadWallpaper();
-	void paintEvent(QPaintEvent *);
-	void resizeEvent(QResizeEvent *);
+	void paintEvent(QPaintEvent*);
+	void resizeEvent(QResizeEvent* event);
 
 public slots:
 	void orientationChanged();
 
 private:
+	RotatingBackground(const RotatingBackground& old);
+	RotatingBackground operator= (const RotatingBackground& old);
+
 	QPixmap iWallpaperLandscape;
 	QPixmap iWallpaperPortrait;
 };
