@@ -39,8 +39,8 @@ Settings::Settings(QWidget *parent) :
 Settings::~Settings()
 {
 	iQSettings->sync();
-	delete iQSettings;
-    delete ui;
+	delete iQSettings; iQSettings=0;
+	delete ui; ui=0;
 }
 
 void Settings::changeEvent(QEvent *e)
